ParticleFactory = Core.class(Sprite)
 
function ParticleFactory:init(config)
 
	self.conf = {
		autoStart = true,
		width = 7,
		height = 7,
		density = 100,
		texture = "Assets/Images/rating.png",
		particleColor = 0xAAAA00,
		alphaSpeed = 0.03,
		sizeSpeed = 0.03,
		sizeMin = 10,
		sizeMax = 19,
		rotationMin = 5 ,
		rotationMax = 10,
		speedMin = 10,
		speedMax = 200
	}
 
	if config then
		for key,value in pairs(config) do
			self.conf[key]= value
		end
	end
 
	self.count = self.conf.density * self.conf.height * self.conf.width * 0.002
 
	self.started = false
 
	if self.conf.autoStart == true then
 
		self:start()
 
	end
end
 
function ParticleFactory:createParticles()
 
	self.particles = Particles.new()
 
	local p
	for y=0,self.count do
		local angle = math.random()*math.pi*2;
		local length =  math.random();
		local xPos = math.cos(angle) * (self.conf.width/2) *length
		local yPos = math.sin(angle) * (self.conf.height/2) *length
 
		--Todo speed config
		p= self.particles:addParticles(xPos,yPos,math.random(self.conf.sizeMin*10,self.conf.sizeMax*10) / 10)
 
		local speedX = (math.random(self.conf.speedMin,self.conf.speedMax) / 100) * (xPos/ math.abs(xPos)) 
		local speedY =  (math.random(self.conf.speedMin,self.conf.speedMax) / 100) * (yPos/ math.abs(yPos))
 
		self.particles:setParticleTtl(p,10000)
		self.particles:setParticleSpeed(p,speedX,speedY, math.random(self.conf.rotationMin,self.conf.rotationMax) / 10)
		self.particles:setParticleColor(p,self.conf.particleColor,math.random(5,10)/10)
 
	end
 
	--self.particles:setTexture(Texture.new(self.conf.texture,true))
	self:addChild(self.particles)
 
end
 
 
function ParticleFactory:start()
 
	self:createParticles()
 
	self:addEventListener(Event.ENTER_FRAME,self.onEnterFrame,self)
	self.started = true
 
end
 
function ParticleFactory:onEnterFrame(e)
 
	local canRemove = true
	for y=1,self.count+1 do
		local color,alpha = self.particles:getParticleColor(y)
		alpha= alpha - (self.conf.alphaSpeed * e.deltaTime * 60)
		self.particles:setParticleColor(y,color,alpha)
		--self.particles:setParticleSize(y,self.particles:getParticleSize(y)-self.conf.sizeSpeed)
 
		if alpha > 0 then
			canRemove=false
		end
 
	end
 
	if canRemove then
		self:removeEventListener(Event.ENTER_FRAME,self.onEnterFrame,self)
		self.particles:removeParticles()
		self:removeFromParent()
		self = nil
	end
 
end
 
 
function ParticleFactory:getWidth()
	return self.conf.width
end
 
function ParticleFactory:getHeight()
	return self.conf.height
end